@@ -1,7 +1,7 @@
 /*
  *  Instantiate the clock driver shell.
  *
- *  $Id: clockdrv.c,v 1.6 2004/04/21 16:01:36 ralf Exp $
+ *  $Id$
  */
 
 #include <bsp.h>
@@ -26,7 +26,7 @@ typedef struct {
 /* 8 microseconds per click, 125,000 per second */
 
 /* XXX should check that microseconds_per_tick is >= 8 */
-void Clock_driver_support_initialize_hardware()
+void Clock_driver_support_initialize_hardware(void)
 {
   timer_hw_t *t = TIMER_BASE;
 
@@ -36,18 +36,18 @@ void Clock_driver_support_initialize_hardware()
   t->cr  = 0xA1;  /* enable timer */
 }
 
-void Clock_driver_support_at_tick()
+void Clock_driver_support_at_tick(void)
 {
   timer_hw_t *t = TIMER_BASE;
 
   t->sr  = 0xA0;  /* Negate timer interrupt request */
 }
 
-void Clock_driver_support_shutdown_hardware()
+void Clock_driver_support_shutdown_hardware(void)
 {
   timer_hw_t *t = TIMER_BASE;
 
   t->cr  = 0xA0;  /* initialize with timer disabled */
 }
 
-#include "../../../shared/clockdrv_shell.c"
+#include "../../../shared/clockdrv_shell.h"
