@@ -75,7 +75,7 @@ struct ambapp_rmap_priv {
 	/* IRQ HANDLING */
 	int			irq_support;
 	genirq_t		genirq;
-	LEON3_IrqCtrl_Regs_Map	*irq;
+	struct irqmp_regs	*irq;
 
 	/* Access routines */
 	struct drvmgr_func	funcs[INHERIT_LENGTH+3];
@@ -195,14 +195,6 @@ void *ambapp_rmap_memcpy(
 	return dest;
 }
 
-/* AMBA PP find routines */
-int ambapp_rmap_dev_find(struct ambapp_dev *dev, int index, void *arg)
-{
-	/* Found IRQ/GRPCI controller, stop */
-	*(struct ambapp_dev **)arg = dev;
-	return 1;
-}
-
 /* Function called from Driver Manager Initialization Stage 1 */
 int ambapp_rmap_init1(struct drvmgr_dev *dev)
 {
@@ -261,17 +253,17 @@ int ambapp_rmap_init1(struct drvmgr_dev *dev)
 		ambapp_print(&priv->abus, 10);
 
 	/* Find IRQ controller */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_APB_SLVS), VENDOR_GAISLER, GAISLER_IRQMP, ambapp_rmap_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (void *)ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_APB_SLVS),
+					VENDOR_GAISLER, GAISLER_IRQMP,
+					ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		/* Silent error if not IRQ controller is found and IRQ support
 		 * is disabled
 		 */
 		if ( priv->irq_support )
 			return -4;
 	} else {
-		priv->irq = (LEON3_IrqCtrl_Regs_Map *)
-			(((struct ambapp_apb_info *)tmp->devinfo)->start);
+		priv->irq = (struct irqmp_regs *)DEV_TO_APB(tmp)->start;
 		/* Set up IRQ controller */
 		WRITE_REG(priv, &priv->irq->iclear, 0xffff);
 		WRITE_REG(priv, &priv->irq->ilevel, 0);
