@@ -12,12 +12,12 @@
  *  2007-09-07, Ported GBIT support from 4.6.5
  */
 #include <rtems.h>
-
-#define GRETH_SUPPORTED
 #define _KERNEL
 #define CPU_U32_FIX
 #include <bsp.h>
 
+#ifdef GRETH_SUPPORTED
+
 #include <inttypes.h>
 #include <errno.h>
 #include <rtems/bspIo.h>
@@ -67,13 +67,10 @@ extern rtems_isr_entry set_vector( rtems_isr_entry, rtems_vector_number, int );
 extern void ipalign(struct mbuf *m);
 #endif
 
-static inline unsigned int sparc_load_no_cache(unsigned int addr)
-{
-	unsigned int tmp;
-	asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
-	return tmp;
-}
-#define NO_CACHE_LOAD(addr) sparc_load_no_cache((unsigned int)addr)
+/* Used when reading from memory written by GRETH DMA unit */
+#ifndef GRETH_MEM_LOAD
+#define GRETH_MEM_LOAD(addr) (*(volatile unsigned int *)(addr))
+#endif
 
 /*
  * Number of OCs supported by this driver
@@ -110,6 +107,10 @@ static inline unsigned int sparc_load_no_cache(unsigned int addr)
 #ifndef GRETH_AUTONEGO_TIMEOUT_MS
 #define GRETH_AUTONEGO_TIMEOUT_MS 4000
 #endif
+const struct timespec greth_tan = {
+   GRETH_AUTONEGO_TIMEOUT_MS/1000,
+   GRETH_AUTONEGO_TIMEOUT_MS*1000000
+};
 
 /* For optimizing the autonegotiation time */
 #define GRETH_AUTONEGO_PRINT_TIME
@@ -166,8 +167,8 @@ struct greth_softc
    int gb;
    int gbit_mac;
    int auto_neg;
-   unsigned int auto_neg_time;
-   
+   struct timespec auto_neg_time;
+
    /*
     * Statistics
     */
@@ -281,8 +282,9 @@ static void print_init_info(struct greth_softc *sc)
         printf("Half Duplex\n");
     }
 #ifdef GRETH_AUTONEGO_PRINT_TIME
-    if ( sc->auto_neg ){
-        printf("Autonegotiation Time: %dms\n",sc->auto_neg_time);
+    if ( sc->auto_neg ) {
+        printf("Autonegotiation Time: %dms\n", sc->auto_neg_time.tv_sec * 1000 +
+               sc->auto_neg_time.tv_nsec / 1000000);
     }
 #endif
 }
@@ -301,8 +303,7 @@ greth_initialize_hardware (struct greth_softc *sc)
     int phystatus;
     int tmp1;
     int tmp2;
-    unsigned int msecs;
-    struct timeval tstart, tnow;
+    struct timespec tstart, tnow;
 
     greth_regs *regs;
 
@@ -341,33 +342,17 @@ greth_initialize_hardware (struct greth_softc *sc)
     sc->fd = 0;
     sc->sp = 0;
     sc->auto_neg = 0;
-    sc->auto_neg_time = 0;
+    _Timespec_Set_to_zero(&sc->auto_neg_time);
     if ((phyctrl >> 12) & 1) {
             /*wait for auto negotiation to complete*/
-            msecs = 0;
             sc->auto_neg = 1;
-            if ( rtems_clock_get_tod_timeval(&tstart) == RTEMS_NOT_DEFINED){
-                /* Not inited, set to epoch */
-                rtems_time_of_day time;
-                time.year   = 1988;
-                time.month  = 1;
-                time.day    = 1;
-                time.hour   = 0;
-                time.minute = 0;
-                time.second = 0;
-                time.ticks  = 0;
-                rtems_clock_set(&time);
-
-                tstart.tv_sec = 0;
-                tstart.tv_usec = 0;
-                rtems_clock_get_tod_timeval(&tstart);
-            }
+            if (rtems_clock_get_uptime(&tstart) != RTEMS_SUCCESSFUL)
+                    printk("rtems_clock_get_uptime failed\n");
             while (!(((phystatus = read_mii(sc, phyaddr, 1)) >> 5) & 1)) {
-                    if ( rtems_clock_get_tod_timeval(&tnow) != RTEMS_SUCCESSFUL )
-                      printk("rtems_clock_get_tod_timeval failed\n\r");
-                    msecs = (tnow.tv_sec-tstart.tv_sec)*1000+(tnow.tv_usec-tstart.tv_usec)/1000;
-                    if ( msecs > GRETH_AUTONEGO_TIMEOUT_MS ){
-                            sc->auto_neg_time = msecs;
+                    if (rtems_clock_get_uptime(&tnow) != RTEMS_SUCCESSFUL)
+                            printk("rtems_clock_get_uptime failed\n");
+                    _Timespec_Subtract(&tstart, &tnow, &sc->auto_neg_time);
+                    if (_Timespec_Greater_than(&sc->auto_neg_time, &greth_tan)) {
                             sc->auto_neg = -1; /* Failed */
                             tmp1 = read_mii(sc, phyaddr, 0);
                             sc->gb = ((phyctrl >> 6) & 1) && !((phyctrl >> 13) & 1);
@@ -375,8 +360,9 @@ greth_initialize_hardware (struct greth_softc *sc)
                             sc->fd = (phyctrl >> 8) & 1;
                             goto auto_neg_done;
                     }
+                    /* Wait about 30ms, time is PHY dependent */
+                    rtems_task_wake_after(rtems_clock_get_ticks_per_second()/32);
             }
-            sc->auto_neg_time = msecs;
             sc->phydev.adv = read_mii(sc, phyaddr, 4);
             sc->phydev.part = read_mii(sc, phyaddr, 5);
             if ((phystatus >> 8) & 1) {
@@ -605,7 +591,7 @@ greth_Daemon (void *arg)
     /* Scan for Received packets */
 again:
     while (!((len_status =
-		    NO_CACHE_LOAD(&dp->rxdesc[dp->rx_ptr].ctrl)) & GRETH_RXD_ENABLE))
+		    GRETH_MEM_LOAD(&dp->rxdesc[dp->rx_ptr].ctrl)) & GRETH_RXD_ENABLE))
 	    {
                     bad = 0;
                     if (len_status & GRETH_RXD_TOOLONG)
@@ -722,7 +708,7 @@ sendpacket (struct ifnet *ifp, struct mbuf *m)
     /*
      * Is there a free descriptor available?
      */
-    if ( NO_CACHE_LOAD(&dp->txdesc[dp->tx_ptr].ctrl) & GRETH_TXD_ENABLE ){
+    if (GRETH_MEM_LOAD(&dp->txdesc[dp->tx_ptr].ctrl) & GRETH_TXD_ENABLE){
             /* No. */
             inside = 0;
             return 1;
@@ -732,7 +718,7 @@ sendpacket (struct ifnet *ifp, struct mbuf *m)
     n = m;
 
     len = 0;
-    temp = (unsigned char *) NO_CACHE_LOAD(&dp->txdesc[dp->tx_ptr].addr);
+    temp = (unsigned char *) GRETH_MEM_LOAD(&dp->txdesc[dp->tx_ptr].addr);
     drvmgr_translate(dp->dev, 1, 1, (void *)temp, (void **)&temp);
 #ifdef GRETH_DEBUG
     printf("TXD: 0x%08x : BUF: 0x%08x\n", (int) m->m_data, (int) temp);
@@ -896,7 +882,7 @@ int greth_process_tx_gbit(struct greth_softc *sc)
      */
     for (;;){
         /* Reap Sent packets */
-        while((sc->tx_cnt > 0) && !(NO_CACHE_LOAD(&sc->txdesc[sc->tx_dptr].ctrl) & GRETH_TXD_ENABLE)) {
+        while((sc->tx_cnt > 0) && !(GRETH_MEM_LOAD(&sc->txdesc[sc->tx_dptr].ctrl) & GRETH_TXD_ENABLE)) {
             m_free(sc->txmbuf[sc->tx_dptr]);
             sc->tx_dptr = (sc->tx_dptr + 1) % sc->txbufs;
             sc->tx_cnt--;
@@ -1405,3 +1391,5 @@ static int greth_info(
 	return DRVMGR_OK;
 }
 #endif
+
+#endif
