@@ -91,7 +91,7 @@ struct gr_rasta_adcdac_priv {
 
 	/* GR-RASTA-ADCDAC */
 	struct gr_rasta_adcdac_ver	*version;
-	LEON3_IrqCtrl_Regs_Map		*irq;
+	struct irqmp_regs		*irq;
 	struct grpci_regs		*grpci;
 	struct drvmgr_map_entry		bus_maps_down[3];
 	struct drvmgr_map_entry		bus_maps_up[2];
@@ -217,14 +217,6 @@ void gr_rasta_adcdac_isr (void *arg)
 	DBG("RASTA-ADCDAC-IRQ: 0x%x\n", tmp);
 }
 
-/* AMBA PP find routines */
-int gr_rasta_adcdac_dev_find(struct ambapp_dev *dev, int index, void *arg)
-{
-	/* Found IRQ/GRPCI controller, stop */
-	*(struct ambapp_dev **)arg = dev;
-	return 1;
-}
-
 int gr_rasta_adcdac_hw_init1(struct gr_rasta_adcdac_priv *priv)
 {
 	uint32_t data;
@@ -291,9 +283,11 @@ int gr_rasta_adcdac_hw_init1(struct gr_rasta_adcdac_priv *priv)
 	*page0 = 0x80000000;	
 
 	/* Find GRPCI controller */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_APB_SLVS), VENDOR_GAISLER, GAISLER_PCIFBRG, gr_rasta_adcdac_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (void *)ambapp_for_each(&priv->abus,
+					(OPTIONS_ALL|OPTIONS_APB_SLVS),
+					VENDOR_GAISLER, GAISLER_PCIFBRG,
+					ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -3;
 	}
 	priv->grpci = (struct grpci_regs *)((struct ambapp_apb_info *)tmp->devinfo)->start;
@@ -306,12 +300,14 @@ int gr_rasta_adcdac_hw_init1(struct gr_rasta_adcdac_priv *priv)
 	priv->grpci->page1 = 0x40000000;
 
 	/* Find IRQ controller */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_APB_SLVS), VENDOR_GAISLER, GAISLER_IRQMP, gr_rasta_adcdac_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (void *)ambapp_for_each(&priv->abus,
+					(OPTIONS_ALL|OPTIONS_APB_SLVS),
+					VENDOR_GAISLER, GAISLER_IRQMP,
+					ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -4;
 	}
-	priv->irq = (LEON3_IrqCtrl_Regs_Map *)(((struct ambapp_apb_info *)tmp->devinfo)->start);
+	priv->irq = (struct irqmp_regs *)DEV_TO_APB(tmp)->start;
 	/* Set up GR-RASTA-ADCDAC irq controller */
 	priv->irq->iclear = 0xffff;
 	priv->irq->ilevel = 0;
@@ -332,9 +328,11 @@ int gr_rasta_adcdac_hw_init1(struct gr_rasta_adcdac_priv *priv)
 	priv->bus_maps_down[2].size = 0;
 
 	/* Find GRPCI controller AHB Slave interface */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_AHB_SLVS), VENDOR_GAISLER, GAISLER_PCIFBRG, gr_rasta_adcdac_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (void *)ambapp_for_each(&priv->abus,
+					(OPTIONS_ALL|OPTIONS_AHB_SLVS),
+					VENDOR_GAISLER, GAISLER_PCIFBRG,
+					ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -5;
 	}
 	ahb = (struct ambapp_ahb_info *)tmp->devinfo;
