@@ -70,16 +70,6 @@ struct grpci_regs {
 	volatile unsigned int stat_cmd;
 };
 
-struct grgpio_regs {
-	volatile unsigned int io_data;		/* 0x00 I/O port data register */
-	volatile unsigned int io_output;	/* 0x04 I/O port output register */
-	volatile unsigned int io_dir;		/* 0x08 I/O port direction register */
-	volatile unsigned int imask;		/* 0x0C Interrupt mask register */
-	volatile unsigned int ipol;		/* 0x10 Interrupt polarity register */
-	volatile unsigned int iedge;		/* 0x14 Interrupt edge register */
-	volatile unsigned int ibypass;		/* 0x18 Bypass register */
-};
-
 struct gr_rasta_tmtc_ver {
 	const unsigned int	amba_freq_hz;	/* The frequency */
 	const unsigned int	amba_ioarea;	/* The address where the PnP IOAREA starts at */
@@ -101,7 +91,7 @@ struct gr_rasta_tmtc_priv {
 
 	/* GR-RASTA-TMTC */
 	struct gr_rasta_tmtc_ver	*version;
-	LEON3_IrqCtrl_Regs_Map		*irq;
+	struct irqmp_regs		*irq;
 	struct grpci_regs		*grpci;
 	struct grgpio_regs		*gpio;
 	struct drvmgr_map_entry		bus_maps_down[3];
@@ -229,19 +219,10 @@ void gr_rasta_tmtc_isr (void *arg)
 	DBG("RASTA-TMTC-IRQ: 0x%x\n", tmp);
 }
 
-/* AMBA PP find routines */
-int gr_rasta_tmtc_dev_find(struct ambapp_dev *dev, int index, void *arg)
-{
-	/* Found IRQ/GRPCI controller, stop */
-	*(struct ambapp_dev **)arg = dev;
-	return 1;
-}
-
 int gr_rasta_tmtc_hw_init(struct gr_rasta_tmtc_priv *priv)
 {
 	unsigned int *page0 = NULL;
 	struct ambapp_dev *tmp;
-	int status;
 	struct ambapp_ahb_info *ahb;
 	unsigned int pci_freq_hz;
 	pci_dev_t pcidev = priv->pcidev;
@@ -310,9 +291,11 @@ int gr_rasta_tmtc_hw_init(struct gr_rasta_tmtc_priv *priv)
 	*page0 = AHB1_BASE_ADDR;
 
 	/* Find GRPCI controller */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_APB_SLVS), VENDOR_GAISLER, GAISLER_PCIFBRG, gr_rasta_tmtc_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (void *)ambapp_for_each(&priv->abus,
+					(OPTIONS_ALL|OPTIONS_APB_SLVS),
+					VENDOR_GAISLER, GAISLER_PCIFBRG,
+					ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -3;
 	}
 	priv->grpci = (struct grpci_regs *)((struct ambapp_apb_info *)tmp->devinfo)->start;
@@ -325,21 +308,25 @@ int gr_rasta_tmtc_hw_init(struct gr_rasta_tmtc_priv *priv)
 	priv->grpci->page1 = 0x40000000;
 
 	/* Find IRQ controller, Clear all current IRQs */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_APB_SLVS), VENDOR_GAISLER, GAISLER_IRQMP, gr_rasta_tmtc_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (void *)ambapp_for_each(&priv->abus,
+					(OPTIONS_ALL|OPTIONS_APB_SLVS),
+					VENDOR_GAISLER, GAISLER_IRQMP,
+					ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -4;
 	}
-	priv->irq = (LEON3_IrqCtrl_Regs_Map *)(((struct ambapp_apb_info *)tmp->devinfo)->start);
+	priv->irq = (struct irqmp_regs *)DEV_TO_APB(tmp)->start;
 	/* Set up GR-RASTA-TMTC irq controller */
 	priv->irq->mask[0] = 0;
 	priv->irq->iclear = 0xffffffff;
 	priv->irq->ilevel = 0;
 
 	/* Find First GPIO controller */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_APB_SLVS), VENDOR_GAISLER, GAISLER_GPIO, gr_rasta_tmtc_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (void *)ambapp_for_each(&priv->abus,
+					(OPTIONS_ALL|OPTIONS_APB_SLVS),
+					VENDOR_GAISLER, GAISLER_GPIO,
+					ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -5;
 	}
 	priv->gpio = (struct grgpio_regs *) (((struct ambapp_apb_info *)tmp->devinfo)->start);
@@ -347,10 +334,10 @@ int gr_rasta_tmtc_hw_init(struct gr_rasta_tmtc_priv *priv)
 	priv->gpio->imask = 0;
 	priv->gpio->ipol = 0;
 	priv->gpio->iedge = 0;
-	priv->gpio->ibypass = 0;
+	priv->gpio->bypass = 0;
 	/* Set up GR-RASTA-TMTC GPIO controller to select GRTM and GRTC */
-	priv->gpio->io_output = (GR_TMTC_GPIO_GRTM_SEL|GR_TMTC_GPIO_TRANSP_CLK) | (GR_TMTC_GPIO_TC_BIT_LOCK|GR_TMTC_GPIO_TC_RF_AVAIL|GR_TMTC_GPIO_TC_ACTIVE_HIGH|GR_TMTC_GPIO_TC_RISING_CLK);
-	priv->gpio->io_dir = 0xffffffff;
+	priv->gpio->output = (GR_TMTC_GPIO_GRTM_SEL|GR_TMTC_GPIO_TRANSP_CLK) | (GR_TMTC_GPIO_TC_BIT_LOCK|GR_TMTC_GPIO_TC_RF_AVAIL|GR_TMTC_GPIO_TC_ACTIVE_HIGH|GR_TMTC_GPIO_TC_RISING_CLK);
+	priv->gpio->dir = 0xffffffff;
 	DBG("GR-TMTC GPIO: 0x%x\n", (unsigned int)priv->gpio);
 
 	/* Enable DMA by enabling PCI target as master */
@@ -371,9 +358,11 @@ int gr_rasta_tmtc_hw_init(struct gr_rasta_tmtc_priv *priv)
 	priv->bus_maps_down[2].size = 0;
 
 	/* Find GRPCI controller AHB Slave interface */
-	tmp = NULL;
-	status = ambapp_for_each(&priv->abus, (OPTIONS_ALL|OPTIONS_AHB_SLVS), VENDOR_GAISLER, GAISLER_PCIFBRG, gr_rasta_tmtc_dev_find, &tmp);
-	if ( (status != 1) || !tmp ) {
+	tmp = (struct ambapp_dev *)ambapp_for_each(&priv->abus,
+				(OPTIONS_ALL|OPTIONS_AHB_SLVS),
+				VENDOR_GAISLER, GAISLER_PCIFBRG,
+				ambapp_find_by_idx, NULL);
+	if ( !tmp ) {
 		return -6;
 	}
 	ahb = (struct ambapp_ahb_info *)tmp->devinfo;
