@@ -12,10 +12,10 @@
  */
 
 #include <rtems.h>
-
-#define GRETH_SUPPORTED
 #include <bsp.h>
 
+#ifdef GRETH_SUPPORTED
+
 #include <inttypes.h>
 #include <errno.h>
 #include <rtems/bspIo.h>
@@ -42,26 +42,16 @@
 #undef free
 #endif
 
-#if defined(__m68k__)
-extern m68k_isr_entry set_vector( rtems_isr_entry, rtems_vector_number, int );
-#else
-extern rtems_isr_entry set_vector( rtems_isr_entry, rtems_vector_number, int );
-#endif
-
-
 /* #define GRETH_DEBUG */
 
 #ifdef CPU_U32_FIX
 extern void ipalign(struct mbuf *m);
 #endif
 
-static inline unsigned int sparc_load_no_cache(unsigned int addr)
-{
-	unsigned int tmp;
-	asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
-	return tmp;
-}
-#define NO_CACHE_LOAD(addr) sparc_load_no_cache(addr)
+/* Used when reading from memory written by GRETH DMA unit */
+#ifndef GRETH_MEM_LOAD
+#define GRETH_MEM_LOAD(addr) (*(volatile unsigned int *)(addr))
+#endif
 
 /*
  * Number of OCs supported by this driver
@@ -98,6 +88,10 @@ static inline unsigned int sparc_load_no_cache(unsigned int addr)
 #ifndef GRETH_AUTONEGO_TIMEOUT_MS
 #define GRETH_AUTONEGO_TIMEOUT_MS 4000
 #endif
+const struct timespec greth_tan = {
+   GRETH_AUTONEGO_TIMEOUT_MS/1000,
+   GRETH_AUTONEGO_TIMEOUT_MS*1000000
+};
 
 /* For optimizing the autonegotiation time */
 #define GRETH_AUTONEGO_PRINT_TIME
@@ -133,7 +127,7 @@ struct greth_softc
    greth_rxtxdesc *rxdesc;
    struct mbuf **rxmbuf;
    struct mbuf **txmbuf;
-   rtems_vector_number vector;
+   int irq;
 
    /* TX descriptor interrupt generation */
    int tx_int_gen;
@@ -148,7 +142,7 @@ struct greth_softc
    int gb;
    int gbit_mac;
    int auto_neg;
-   unsigned int auto_neg_time;
+   struct timespec auto_neg_time;
 
    /*
     * Statistics
@@ -186,8 +180,7 @@ static char *almalloc(int sz)
 
 /* GRETH interrupt handler */
 
-rtems_isr
-greth_interrupt_handler (rtems_vector_number v)
+void greth_interrupt_handler (void *arg)
 {
         uint32_t status;
         uint32_t ctrl;
@@ -206,20 +199,20 @@ greth_interrupt_handler (rtems_vector_number v)
                 ctrl &= ~GRETH_CTRL_RXIRQ;
                 events |= INTERRUPT_EVENT;
         }
-
+        
         if ( (ctrl & GRETH_CTRL_TXIRQ) && (status & (GRETH_STATUS_TXERR | GRETH_STATUS_TXIRQ)) )
         {
                 greth.txInterrupts++;
                 ctrl &= ~GRETH_CTRL_TXIRQ;
                 events |= GRETH_TX_WAIT_EVENT;
         }
-
+        
         /* Clear interrupt sources */
         greth.regs->ctrl = ctrl;
-
+        
         /* Send the event(s) */
         if ( events )
-                rtems_event_send (greth.daemonTid, events);
+            rtems_event_send (greth.daemonTid, events);
 }
 
 static uint32_t read_mii(uint32_t phy_addr, uint32_t reg_addr)
@@ -265,8 +258,9 @@ static void print_init_info(struct greth_softc *sc)
                 printf("Half Duplex\n");
         }
 #ifdef GRETH_AUTONEGO_PRINT_TIME
-        if ( sc->auto_neg ){
-          printf("Autonegotiation Time: %dms\n",sc->auto_neg_time);
+        if ( sc->auto_neg ) {
+          printf("Autonegotiation Time: %dms\n", sc->auto_neg_time.tv_sec * 1000 +
+                 sc->auto_neg_time.tv_nsec / 1000000);
         }
 #endif
 }
@@ -285,8 +279,7 @@ greth_initialize_hardware (struct greth_softc *sc)
     int phystatus;
     int tmp1;
     int tmp2;
-    unsigned int msecs;
-    struct timeval tstart, tnow;
+    struct timespec tstart, tnow;
 
     greth_regs *regs;
 
@@ -321,33 +314,17 @@ greth_initialize_hardware (struct greth_softc *sc)
     sc->fd = 0;
     sc->sp = 0;
     sc->auto_neg = 0;
-    sc->auto_neg_time = 0;
+    _Timespec_Set_to_zero(&sc->auto_neg_time);
     if ((phyctrl >> 12) & 1) {
             /*wait for auto negotiation to complete*/
-            msecs = 0;
             sc->auto_neg = 1;
-            if ( rtems_clock_get_tod_timeval(&tstart) == RTEMS_NOT_DEFINED){
-                /* Not inited, set to epoch */
-                rtems_time_of_day time;
-                time.year   = 1988;
-                time.month  = 1;
-                time.day    = 1;
-                time.hour   = 0;
-                time.minute = 0;
-                time.second = 0;
-                time.ticks  = 0;
-                rtems_clock_set(&time);
-
-                tstart.tv_sec = 0;
-                tstart.tv_usec = 0;
-                rtems_clock_get_tod_timeval(&tstart);
-            }
+            if (rtems_clock_get_uptime(&tstart) != RTEMS_SUCCESSFUL)
+                    printk("rtems_clock_get_uptime failed\n");
             while (!(((phystatus = read_mii(phyaddr, 1)) >> 5) & 1)) {
-                    if ( rtems_clock_get_tod_timeval(&tnow) != RTEMS_SUCCESSFUL )
-                      printk("rtems_clock_get_tod_timeval failed\n\r");
-                    msecs = (tnow.tv_sec-tstart.tv_sec)*1000+(tnow.tv_usec-tstart.tv_usec)/1000;
-                    if ( msecs > GRETH_AUTONEGO_TIMEOUT_MS ){
-                            sc->auto_neg_time = msecs;
+                    if (rtems_clock_get_uptime(&tnow) != RTEMS_SUCCESSFUL)
+                            printk("rtems_clock_get_uptime failed\n");
+                    _Timespec_Subtract(&tstart, &tnow, &sc->auto_neg_time);
+                    if (_Timespec_Greater_than(&sc->auto_neg_time, &greth_tan)) {
                             sc->auto_neg = -1; /* Failed */
                             tmp1 = read_mii(phyaddr, 0);
                             sc->gb = ((phyctrl >> 6) & 1) && !((phyctrl >> 13) & 1);
@@ -355,8 +332,9 @@ greth_initialize_hardware (struct greth_softc *sc)
                             sc->fd = (phyctrl >> 8) & 1;
                             goto auto_neg_done;
                     }
+                    /* Wait about 30ms, time is PHY dependent */
+                    rtems_task_wake_after(rtems_clock_get_ticks_per_second()/32);
             }
-            sc->auto_neg_time = msecs;
             sc->phydev.adv = read_mii(phyaddr, 4);
             sc->phydev.part = read_mii(phyaddr, 5);
             if ((phystatus >> 8) & 1) {
@@ -397,7 +375,7 @@ auto_neg_done:
     phystatus = read_mii(phyaddr, 1);
 
     /*Read out PHY info if extended registers are available */
-    if (phystatus & 1) {
+    if (phystatus & 1) {  
             tmp1 = read_mii(phyaddr, 2);
             tmp2 = read_mii(phyaddr, 3);
 
@@ -497,8 +475,9 @@ auto_neg_done:
     /* clear all pending interrupts */
     regs->status = 0xffffffff;
     
-    /* install interrupt vector */
-    set_vector(greth_interrupt_handler, sc->vector, 2);
+    /* install interrupt handler */
+    rtems_interrupt_handler_install(sc->irq, "greth", RTEMS_INTERRUPT_SHARED,
+                                    greth_interrupt_handler, sc);
 
     regs->ctrl |= GRETH_CTRL_RXEN | (sc->fd << 4) | GRETH_CTRL_RXIRQ | (sc->sp << 7) | (sc->gb << 8);
 
@@ -575,7 +554,7 @@ greth_Daemon (void *arg)
                 greth_process_tx_gbit(dp);
             else
                 greth_process_tx(dp);
-
+            
             /* If we didn't get a RX interrupt we don't process it */
             if ( (events & INTERRUPT_EVENT) == 0 )
                 continue;
@@ -588,7 +567,7 @@ greth_Daemon (void *arg)
     /* Scan for Received packets */
 again:
     while (!((len_status =
-		    NO_CACHE_LOAD(&dp->rxdesc[dp->rx_ptr].ctrl)) & GRETH_RXD_ENABLE))
+		    GRETH_MEM_LOAD(&dp->rxdesc[dp->rx_ptr].ctrl)) & GRETH_RXD_ENABLE))
 	    {
                     bad = 0;
                     if (len_status & GRETH_RXD_TOOLONG)
@@ -633,15 +612,15 @@ again:
 
                             eh = mtod (m, struct ether_header *);
 
-														/* OVERRIDE CACHED ETHERNET HEADER FOR NON-SNOOPING SYSTEMS */
-														addr = (unsigned int)eh;
-														asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
-														addr+=4;
-														asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
-														addr+=4;
-														asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
-														addr+=4;
-														asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
+                            /* OVERRIDE CACHED ETHERNET HEADER FOR NON-SNOOPING SYSTEMS */
+                            addr = (unsigned int)eh;
+                            asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
+                            addr+=4;
+                            asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
+                            addr+=4;
+                            asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
+                            addr+=4;
+                            asm volatile (" lda [%1] 1, %0\n" : "=r"(tmp) : "r"(addr) );
 
                             m->m_data += sizeof (struct ether_header);
 #ifdef CPU_U32_FIX
@@ -674,7 +653,7 @@ again:
                     rtems_interrupt_enable(level);
                     dp->rx_ptr = (dp->rx_ptr + 1) % dp->rxbufs;
             }
-        
+
         /* Always scan twice to avoid deadlock */
         if ( first ){
             first=0;
@@ -701,21 +680,21 @@ sendpacket (struct ifnet *ifp, struct mbuf *m)
     /*printf("Send packet entered\n");*/
     if (inside) printf ("error: sendpacket re-entered!!\n");
     inside = 1;
-    
+
     /*
      * Is there a free descriptor available?
      */
-    if ( NO_CACHE_LOAD(&dp->txdesc[dp->tx_ptr].ctrl) & GRETH_TXD_ENABLE ){
+    if (GRETH_MEM_LOAD(&dp->txdesc[dp->tx_ptr].ctrl) & GRETH_TXD_ENABLE){
             /* No. */
             inside = 0;
             return 1;
     }
-    
+
     /* Remember head of chain */
     n = m;
 
     len = 0;
-    temp = (unsigned char *) NO_CACHE_LOAD(&dp->txdesc[dp->tx_ptr].addr);
+    temp = (unsigned char *) GRETH_MEM_LOAD(&dp->txdesc[dp->tx_ptr].addr);
 #ifdef GRETH_DEBUG
     printf("TXD: 0x%08x : BUF: 0x%08x\n", (int) m->m_data, (int) temp);
 #endif
@@ -787,22 +766,23 @@ sendpacket_gbit (struct ifnet *ifp, struct mbuf *m)
             frags++;
             mtmp = mtmp->m_next;
         }
-
+        
         if ( frags > dp->max_fragsize ) 
             dp->max_fragsize = frags;
-
+        
         if ( frags > dp->txbufs ){
             inside = 0;
             printf("GRETH: MBUF-chain cannot be sent. Increase descriptor count.\n");
             return -1;
         }
-
+        
         if ( frags > (dp->txbufs-dp->tx_cnt) ){
             inside = 0;
             /* Return number of fragments */
             return frags;
         }
-
+        
+        
         /* Enable interrupt from descriptor every tx_int_gen
          * descriptor. Typically every 16 descriptor. This
          * is only to reduce the number of interrupts during
@@ -815,11 +795,11 @@ sendpacket_gbit (struct ifnet *ifp, struct mbuf *m)
         }else{
             int_en = 0;
         }
-
+        
         /* At this stage we know that enough descriptors are available */
         for (;;)
         {
-
+                
 #ifdef GRETH_DEBUG
             int i;
             printf("MBUF: 0x%08x, Len: %d : ", (int) m->m_data, m->m_len);
@@ -837,7 +817,7 @@ sendpacket_gbit (struct ifnet *ifp, struct mbuf *m)
                 ctrl = GRETH_TXD_ENABLE | GRETH_TXD_CS | GRETH_TXD_WRAP;
             }
 
-            /* Enable Descriptor */  
+            /* Enable Descriptor */
             if ((m->m_next) == NULL) {
                 dp->txdesc[dp->tx_ptr].ctrl = ctrl | int_en | m->m_len;
                 break;
@@ -851,10 +831,10 @@ sendpacket_gbit (struct ifnet *ifp, struct mbuf *m)
             dp->tx_cnt++;
             m = m->m_next;
         }
-
         dp->txmbuf[dp->tx_ptr] = m;
         dp->tx_ptr = (dp->tx_ptr + 1) % dp->txbufs;
         dp->tx_cnt++;
+
         /* Tell Hardware about newly enabled descriptor */
         rtems_interrupt_disable(level);
         dp->regs->ctrl = dp->regs->ctrl | GRETH_CTRL_TXEN;
@@ -877,7 +857,7 @@ int greth_process_tx_gbit(struct greth_softc *sc)
      */
     for (;;){
         /* Reap Sent packets */
-        while((sc->tx_cnt > 0) && !(NO_CACHE_LOAD(&sc->txdesc[sc->tx_dptr].ctrl) & GRETH_TXD_ENABLE)) {
+        while((sc->tx_cnt > 0) && !(GRETH_MEM_LOAD(&sc->txdesc[sc->tx_dptr].ctrl) & GRETH_TXD_ENABLE)) {
             m_free(sc->txmbuf[sc->tx_dptr]);
             sc->tx_dptr = (sc->tx_dptr + 1) % sc->txbufs;
             sc->tx_cnt--;
@@ -914,7 +894,7 @@ int greth_process_tx_gbit(struct greth_softc *sc)
             sc->next_tx_mbuf = m;
 
             /* Not enough resources, enable interrupt for transmissions
-             * this way we will be informed when more TX-descriptors are
+             * this way we will be informed when more TX-descriptors are 
              * available.
              */
             if ( first ){
@@ -949,8 +929,7 @@ int greth_process_tx(struct greth_softc *sc)
     /*
      * Send packets till queue is empty
      */
-    for (;;)
-    {
+    for (;;){
         if ( sc->next_tx_mbuf ){
             /* Get packet we tried but failed to transmit last time */
             m = sc->next_tx_mbuf;
@@ -981,7 +960,7 @@ int greth_process_tx(struct greth_softc *sc)
             sc->next_tx_mbuf = m;
 
             /* Not enough resources, enable interrupt for transmissions
-             * this way we will be informed when more TX-descriptors are
+             * this way we will be informed when more TX-descriptors are 
              * available.
              */
             if ( first ){
@@ -990,7 +969,7 @@ int greth_process_tx(struct greth_softc *sc)
                 ifp->if_flags |= IFF_OACTIVE;
                 sc->regs->ctrl |= GRETH_CTRL_TXIRQ;
                 rtems_interrupt_enable(level);
-                
+
                 /* We must check again to be sure that we didn't 
                  * miss an interrupt (if a packet was sent just before
                  * enabling interrupts)
@@ -1012,7 +991,7 @@ greth_start (struct ifnet *ifp)
     struct greth_softc *sc = ifp->if_softc;
 
     if ( ifp->if_flags & IFF_OACTIVE )
-        return;
+            return;
 
     if ( sc->gbit_mac ){
         /* No use trying to handle this if we are waiting on GRETH
@@ -1036,16 +1015,17 @@ greth_init (void *arg)
 
     if (sc->daemonTid == 0) {
 
-      /*
-       * Start driver tasks
-       */
-      sc->daemonTid = rtems_bsdnet_newproc ("DCrxtx", 4096,
-                                            greth_Daemon, sc);
+        /*
+         * Start driver tasks
+         */
+        sc->daemonTid = rtems_bsdnet_newproc ("DCrxtx", 4096,
+                                              greth_Daemon, sc);
+
+        /*
+         * Set up GRETH hardware
+         */
+        greth_initialize_hardware (sc);
 
-      /*
-       * Set up GRETH hardware
-       */
-      greth_initialize_hardware (sc);
     }
 
     /*
@@ -1178,7 +1158,7 @@ rtems_greth_driver_attach (struct rtems_bsdnet_ifconfig *config,
 
     sc->acceptBroadcast = !config->ignore_broadcast;
     sc->regs = (void *) chip->base_address;
-    sc->vector = chip->vector;
+    sc->irq = chip->irq;
     sc->txbufs = chip->txd_count;
     sc->rxbufs = chip->rxd_count;
 
@@ -1209,3 +1189,4 @@ rtems_greth_driver_attach (struct rtems_bsdnet_ifconfig *config,
     return 1;
 };
 
+#endif
