@@ -3,33 +3,33 @@
  */
 
 /*
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: semaphore.h,v 1.7 2005/01/28 11:07:14 ralf Exp $
+ *  $Id$
  */
 
 #ifndef _RTEMS_ITRON_SEMAPHORE_H
 #define _RTEMS_ITRON_SEMAPHORE_H
 
+#include <rtems/itron/object.h>
+#include <rtems/score/coresem.h>
+
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#include <rtems/itron/object.h>
-#include <rtems/score/coresem.h>
-
 /*
  *  The following defines the control block used to manage each semaphore.
  */
 
 typedef struct {
   ITRON_Objects_Control   Object;
-  boolean                 is_priority_blocking;
+  bool                    is_priority_blocking;
   CORE_semaphore_Control  semaphore;
 }   ITRON_Semaphore_Control;
 
@@ -48,9 +48,7 @@ ITRON_EXTERN Objects_Information  _ITRON_Semaphore_Information;
  *  This routine performs the initialization necessary for this manager.
  */
 
-void _ITRON_Semaphore_Manager_initialization(
-  uint32_t   maximum_semaphores
-);
+void _ITRON_Semaphore_Manager_initialization(void);
 
 #include <rtems/itron/semaphore.inl>
 
