@@ -1,14 +1,14 @@
 /*
  *  CPU Usage Reporter - Shared Data
  *
- *  COPYRIGHT (c) 1989-2007
+ *  COPYRIGHT (c) 1989-2009
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: cpuusagedata.c,v 1.1 2007/07/18 21:31:49 joel Exp $
+ *  $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -16,18 +16,13 @@
 #endif
 
 #include <rtems.h>
-
 #include <rtems/cpuuse.h>
-
-#if defined(RTEMS_ENABLE_NANOSECOND_RATE_MONOTONIC_STATISTICS) || \
-    defined(RTEMS_ENABLE_NANOSECOND_CPU_USAGE_STATISTICS)
+#ifndef __RTEMS_USE_TICKS_FOR_STATISTICS__
   #include <rtems/score/timespec.h>
-
 #endif
 
-#ifdef RTEMS_ENABLE_NANOSECOND_CPU_USAGE_STATISTICS
+#ifndef __RTEMS_USE_TICKS_FOR_STATISTICS__
   struct timespec    CPU_usage_Uptime_at_last_reset;
 #else
   uint32_t           CPU_usage_Ticks_at_last_reset;
 #endif
-
