@@ -1,5 +1,12 @@
 /*
- *  $Id: condbroadcast.c,v 1.3 2004/04/16 10:01:03 ralf Exp $
+ *  COPYRIGHT (c) 1989-2007.
+ *  On-Line Applications Research Corporation (OAR).
+ *
+ *  The license and distribution terms for this file may be
+ *  found in the file LICENSE in this distribution or at
+ *  http://www.rtems.com/license/LICENSE.
+ *
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -26,5 +33,5 @@ int pthread_cond_broadcast(
   pthread_cond_t   *cond
 )
 {
-  return _POSIX_Condition_variables_Signal_support( cond, TRUE );
+  return _POSIX_Condition_variables_Signal_support( cond, true );
 }
