@@ -2,14 +2,14 @@
  *  ISR Handler
  *
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2008.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: isr.c,v 1.12 2005/01/27 05:57:05 ralf Exp $
+ *  $Id$
  */
 
 #if HAVE_CONFIG_H
@@ -21,6 +21,7 @@
 #include <rtems/score/stack.h>
 #include <rtems/score/interr.h>
 #include <rtems/score/wkspace.h>
+#include <rtems/config.h>
 
 /*  _ISR_Handler_initialization
  *
@@ -33,33 +34,43 @@
 
 void _ISR_Handler_initialization( void )
 {
-  _ISR_Signals_to_thread_executing = FALSE;
+  _ISR_Signals_to_thread_executing = false;
 
   _ISR_Nest_level = 0;
 
+#if (CPU_SIMPLE_VECTORED_INTERRUPTS == TRUE)
   _ISR_Vector_table = _Workspace_Allocate_or_fatal_error(
      sizeof(ISR_Handler_entry) * ISR_NUMBER_OF_VECTORS
   );
+#endif
 
   _CPU_Initialize_vectors();
 
 #if ( CPU_ALLOCATE_INTERRUPT_STACK == TRUE )
 
-  if ( _CPU_Table.interrupt_stack_size < STACK_MINIMUM_SIZE )
+  if ( !_Stack_Is_enough(Configuration.interrupt_stack_size) )
     _Internal_error_Occurred(
       INTERNAL_ERROR_CORE,
-      TRUE,
+      true,
       INTERNAL_ERROR_INTERRUPT_STACK_TOO_SMALL
     );
 
-  _CPU_Interrupt_stack_low =
-    _Workspace_Allocate_or_fatal_error( _CPU_Table.interrupt_stack_size );
+  _CPU_Interrupt_stack_low = _Workspace_Allocate_or_fatal_error(
+    Configuration.interrupt_stack_size
+  );
 
   _CPU_Interrupt_stack_high = _Addresses_Add_offset(
     _CPU_Interrupt_stack_low,
-    _CPU_Table.interrupt_stack_size
+    Configuration.interrupt_stack_size
   );
 
+  /* Interrupt stack might have to be aligned and/or setup
+   * in a specific way.
+   */
+#if defined(_CPU_Interrupt_stack_setup)
+  _CPU_Interrupt_stack_setup(_CPU_Interrupt_stack_low, _CPU_Interrupt_stack_high);
+#endif
+
 #endif
 
 #if ( CPU_HAS_HARDWARE_INTERRUPT_STACK == TRUE )
