@@ -1,22 +1,25 @@
 /*
- *  Simple test program -- simplified version of sample test hello.
+ *  Simple RTEMS startup to call main
  *
- *  COPYRIGHT (c) 1989-1999.
+ *  COPYRIGHT (c) 1989-2009.
  *  On-Line Applications Research Corporation (OAR).
  *
  *  The license and distribution terms for this file may be
  *  found in the file LICENSE in this distribution or at
  *  http://www.rtems.com/license/LICENSE.
  *
- *  $Id: main.c,v 1.6 2004/04/01 15:16:20 ralf Exp $
+ *  $Id$
  */
 
-#define TEST_INIT
+#define CONFIGURE_INIT
 
 #include <bsp.h>
 #include <tmacros.h>  /* instantiate buffering code if needed */
 
 void test_main( void );
+rtems_task Init(
+  rtems_task_argument ignored
+);
 
 rtems_task Init(
   rtems_task_argument ignored
